Module atomlist

Module atomlist 

Some usefult parsing atoms;

Structs

AnyChar
Matches any single character.
CheckInvTool
Matches only if the provided atom doesn’t match.
CheckTool
Only checks the provided atom, without progressing.
EOFChar
Parses only the end of the input
NonEmpty
Discards empty strings from a match.
PredicateAtom
Tool that matches characters which satisfies the provided predicate.
PredicateRefAtom
Tool that matches characters which satisfies the provided ref predicate.
TrueAtom
Matches the empty string, therefore it always matches.

Functions

repeat_any_bounds
Repeat atom with the specified limits without a separator
repeat_any_unbounded
Repeat atom with the specified limits without a separator
repeat_bounds
Repeat atom with the specified limits without a separator
repeat_unbounded
Repeat atom with the specified limits without a separator