pub const fn repeat_unbounded<T>(atom: T, min: usize) -> RepeatAtom<T, TrueAtom>Expand description
Repeat atom with the specified limits without a separator
pub const fn repeat_unbounded<T>(atom: T, min: usize) -> RepeatAtom<T, TrueAtom>Repeat atom with the specified limits without a separator