PredicateRefAtom

Struct PredicateRefAtom 

pub struct PredicateRefAtom<P> { /* private fields */ }
Tool that matches characters which satisfies the provided ref predicate.

See also PredicateAtom.

use minparser::prelude::*;
let lt = MatchHelper::from("aB1৬");
lt.match_atom(PredicateRefAtom::new(char::is_ascii_lowercase)).unwrap()
.match_atom(PredicateRefAtom::new(char::is_ascii_uppercase)).unwrap()
.match_atom(PredicateRefAtom::new(char::is_ascii_digit)).unwrap()
.match_atom(PredicateAtom::new(char::is_numeric)).unwrap();

Implementations

Source

impl<P: Fn(&char) -> bool> PredicateRefAtom<P>

pub const fn new(predicate: P) -> Self

Create a new PredicateRefAtom from a predicate.

pub const fn new_zero_or_more(predicate: P) -> RepeatAnyAtom<Self, TrueAtom>

Creates an atom that matches zero or more occurrences of characters that satisfy the specified predicate.

pub const fn new_one_or_more(predicate: P) -> RepeatAtom<Self, TrueAtom>

Creates an atom that matches one or more occurrences of characters that satisfy the specified predicate.

pub fn parse_char(&self, st: &str) -> Option<(char, usize)>

Tests if the first character satisfy the predicate, and in the affirmative case the matched character and its length are returned.