Module atoms

Module atoms 

Parsing atoms

This module provides the Atom trait and some parsing atoms which incapsulates some basic algorithms which you can use to define more sofisticated ones.

Structs

Match
Data obtained from a successful match.
MatchHelper
String view with accessory matching methods.

Traits

AlwaysAtom
A atom that always matches.
Atom
The main parsing trait