TupData

Struct TupData 

pub struct TupData<D, M> { /* private fields */ }
Available on crate features unstable-features only.
Utility for saving intermediate values.

Complex parsing tools usually use several other tools to perform to perform simple subtasks. However, dealing with many of these tools makes harder to keep consistent both returned data and the total length of the match, which we remember should be consistent with the number of bytes skipped by the View object.

This object keeps an instance of intermediate returned data, actual number of bytes skipped and the last instance of View, keeping them consistent.

Implementations

Source

impl<D, M> TupData<D, M>

pub fn new(this: M) -> Self
where D: Default,

Creates a new instance of this object.

pub fn map_data<DD, F: FnOnce(D) -> DD>(self, f: F) -> TupData<DD, M>

Applies a function to the saved data without modifying other fields.

pub fn get_data(self) -> (D, TupData<(), M>)

Moves stored data outside.

pub fn finalize(self) -> (D, usize, M)

Unpack this objects and returns all its fields.

Source

impl<'a, D> TupData<D, View<'a>>

pub fn chain_replace<T>( self, t: &T, ) -> Result<TupData<T::Data, View<'a>>, T::Error>
where T: Tool<'a>,

Match a Tool and replace stored data with returned data.

pub fn chain_nodata<T>(self, t: &T) -> Result<Self, T::Error>
where T: Tool<'a>,

Match a Tool but discards returned data.

pub fn chain_save<T>( self, t: &T, ) -> Result<TupData<(D, T::Data), View<'a>>, T::Error>
where T: Tool<'a>,

Match a Tool and keeps both saved and returned data.

pub fn chain_save_out<T>(self, t: &T) -> Result<(Self, T::Data), T::Error>
where T: Tool<'a>,

Match a Tool and keeps returned data separated from original data.

pub fn chain_save_at<T>(self, t: &T, to: &mut T::Data) -> Result<Self, T::Error>
where T: Tool<'a>,

Match a Tool and saves returned data at a different location.

Source

impl<'a> TupData<(), View<'a>>

pub fn chain<T>(self, t: &T) -> Result<TupData<T::Data, View<'a>>, T::Error>
where T: Tool<'a>,

Match a Tool object.