Module parser

Parsing tools

This module provides the ParseTool trait and some parsing tools which incapsulates some basic algorithms which you can use to define more sofisticated ones.

Structs

EOFTool
Parses only the end of the input
Named
A named parsing tool.
NamedError
Error type for Named.
OrTool
Tool that matches at least one of two subtools
OrToolErr
Error type for OrTool
PredicateTool
Tool that matches characters which satisfies the provided predicate.
RepeatTool
Tool that matches repetitions with separator
TrueParser
Matches the empty string, therefore it always matches.

Enums

OrToolData
Result type for OrTool
RepeatToolErr
Error type for RepeatTool

Traits

ParseTool
The main parsing trait