pub struct PredicateTool<P> { /* private fields */ }Expand description
Tool that matches characters which satisfies the provided predicate.
A predicate is a function that accepts char and returns an Option: the None variand will
be interpreted as a nonmatch, whereas the Some(d) variant will be interpreted as a match and the
provided data d is stored in the returned View.
Implementations
Sourceimpl<D, P: Fn(char) -> Option<D>> PredicateTool<P>
impl<D, P: Fn(char) -> Option<D>> PredicateTool<P>
Sourcepub const fn new_map(predicate: P) -> Self
pub const fn new_map(predicate: P) -> Self
Create a new PredicateTool from a predicate.
Sourceimpl<'a> PredicateTool<Box<dyn Fn(char) -> Option<char> + 'a>>
impl<'a> PredicateTool<Box<dyn Fn(char) -> Option<char> + 'a>>
Sourcepub fn new_predicate<F: 'a + Fn(char) -> bool>(f: F) -> Self
pub fn new_predicate<F: 'a + Fn(char) -> bool>(f: F) -> Self
Create a new PredicateTool from a function returning a bool.
A false result is interpreted as a None and a true result is converted to
Some(c) with c is the matched character in the view.