Module pos

Module pos 

Positions.

Structs

NoFile
A placeholder that you can use when you don’t want to use the file field in a Position.
Pos
A positioned object, functionally equivalent to a struct containing an object of type T (the wrapped object) and its position as a Position<FILE> object.
Position
A position.

Traits

Posable
A trait for objects with an associated position
PosableMut
A trait for object with mutable position