pub struct Position { /* private fields */ }Expand description
A position.
Characters in a text file can be organizes in a virtual grid in order to easily find characters or parsing errors inside the file. Each file can be divided in multiple lines separated by line feed (U+000A) or carriage return + line feed (U+000D + U+000A).
To find a character then you need just the index of the line containing it (the first line has index 0)
and the character index inside thai line (also called the column).
Implementations