Module predicates

Simple predicates for characters.

This module contains some useful functions in order to analize ASCII and Unicode characters.

A lot of predicates already available for char type are not included here, even if they are quite useful.

Structs

AlphabeticTool
Tests if is_alphabetic is true.
AlphanumericTool
Tests if is_alphanumeric is true.
AsciiAlphabeticTool
Tests if is_ascii_alphabetic is true.
AsciiAlphanumericTool
Tests if is_ascii_alphanumeric is true.
AsciiDigitTool
Tests if is_ascii_digit is true.
AsciiTool
Tests if is_ascii is true.
NumericTool
Tests if is_numeric is true.
WhitespaceTool
Tests if is_whitespace is true.

Functions

is_lu_letter
Unicode lowercase/uppercase letter
is_newline
Tests if a character is a newline character (U+000A, \n). Carriage return (U+000D, \r) is not detected by this function because it is usually followed by the newline character.