Struct NumAppender

pub struct NumAppender<T, const N: u32>(pub Option<T>);
An integer appender.

When T implements Default, AddAssign<T> and MulAssign<usize> then NumAppender<T, N> implements Appender<T> in the following way: if self contains t of type T then pushing s in self updates t into (t * N) + s.

This struct is useful when you want to parse an integer from a text file.

Tuple Fields

0: Option<T>

Implementations

Source

impl<T, const N: u32> NumAppender<T, N>

pub const fn is_empty(&self) -> bool

Tests if it is empty.

Returns true if and only if no value has been pushed.