Struct Pos

pub struct Pos<T, FILE = NoFile> { /* private fields */ }
A positioned object, functionally equivalent to a struct containing an object of type T (the wrapped object) and its position as a Position<FILE> object.

A parser uses characters inside a text file to create more complex objects. When the parsing fails due to a syntax error you must inform the user about it, in particular you need to tell the user where is the error.

This type associates to a type T (usually a token) a Position that allows the user to locate it inside the file

Implementations

Source

impl<T, F> Pos<T, F>

pub const fn new(el: T, pos: Position<F>) -> Self

Creates a new positioned object.

pub const fn new_pos(el: T, file: F, line: u32, column: u32) -> Self

Creates a new positioned object.

pub fn take(self) -> T

Consumes the objects and returns the wrapped element

pub fn take_pos(self) -> Position<F>

Consumes the objects and returns the position

pub fn take_all(self) -> (T, Position<F>)

Consumes the objects and returns both the wrapped element and the position

pub fn test<TF: FnOnce(&T) -> bool>(&self, f: TF) -> bool

Tests the wrapped object

pub fn test_pos<TF: FnOnce(&T, &Position<F>) -> bool>(&self, f: TF) -> bool

Tests both the wrapped object and its position

pub fn map<U, MF: FnOnce(T) -> U>(self, f: MF) -> Pos<U, F>

Apply f at the wrapped object

pub fn map_pos<U, G, MF: FnOnce(T, Position<F>) -> (U, Position<G>)>( self, f: MF, ) -> Pos<U, G>

Apply f at the wrapped object and its position

pub fn make_ref(&self) -> Pos<&T, F>
where F: Clone,

Converts it to a reference

pub fn make_mut(&mut self) -> Pos<&mut T, F>
where F: Clone,

Converts it to a mutable reference

Source

impl<T, E, F> Pos<Result<T, E>, F>

pub fn from_output(out: Pos<T, F>) -> Self

Build result from output

pub fn from_output_pos(out: T, pos: Position<F>) -> Self

Build result from output and position

pub fn from_residual(out: Pos<Result<Infallible, E>, F>) -> Self

Build result from residual

pub fn from_residual_pos(out: Result<Infallible, E>, pos: Position<F>) -> Self

Build result from residual and position

pub const fn from_err_pos(out: E, pos: Position<F>) -> Self

Build result from error and position

pub fn branch(self) -> ControlFlow<Pos<Result<Infallible, E>, F>, Pos<T, F>>

Branch

pub fn throw(self) -> Result<Pos<T, F>, Pos<E, F>>

Converts a Pos<Result<T, E>, F> into Result<Pos<T, F>, Pos<E, F>> that can be used with the ? operator

pub fn throw_el(self) -> Result<Pos<T, F>, E>

Converts a Pos<Result<T, E>, F> into Result<Pos<T, F>, E> that can be used with the ? operator

pub fn throw_err(self) -> Result<T, Pos<E, F>>

Converts a Pos<Result<T, E>, F> into Result<T, Pos<E, F>> that can be used with the ? operator

Source

impl<T, F> Pos<Option<T>, F>

pub fn ok_or<E>(self, err: E) -> Result<Pos<T, F>, Pos<E, F>>

Applies Option::ok_or to the wrapped object and then Pos::throw the resulting object

Errors

If the wrapped value is None then trows passed error

pub fn ok_or_err<E>(self, err: E) -> Result<T, Pos<E, F>>

Applies Option::ok_or to the wrapped object and then Pos::throw_err the resulting object

Errors

If the wrapped value is None then trows passed error

Source

impl<B, C, F> Pos<ControlFlow<B, C>, F>

pub fn try_break(self) -> ControlFlow<Pos<B, F>, C>

Converts a Pos<ControlFlow<B, C>, F> into a ControlFlow<Pos<B, F>, C> by moving the resulting Position to the break case