pub struct PredicateTool<P> { /* private fields */ }Expand description
Tool that matches characters which satisfies the provided predicate.
See also PredicateRefTool.
use minparser::tools::PredicateRefTool;
use minparser::tools::PredicateTool;
let lt = minparser::view::ViewFile::new_default("aB1৬");
lt.match_tool(PredicateRefTool::new(char::is_ascii_lowercase)).unwrap()
.match_tool(PredicateRefTool::new(char::is_ascii_uppercase)).unwrap()
.match_tool(PredicateRefTool::new(char::is_ascii_digit)).unwrap()
.match_tool(PredicateTool::new(char::is_numeric)).unwrap();Implementations
Sourceimpl<P: Fn(char) -> bool> PredicateTool<P>
impl<P: Fn(char) -> bool> PredicateTool<P>
Sourcepub const fn new(predicate: P) -> Self
pub const fn new(predicate: P) -> Self
Create a new PredicateTool from a predicate.
Sourcepub const fn new_zero_or_more(predicate: P) -> RepeatTool<Self, TrueParser>
pub const fn new_zero_or_more(predicate: P) -> RepeatTool<Self, TrueParser>
Creates a tool that matches zero or more occurrences of characters that satisfy the specified predicate.
Sourcepub const fn new_one_or_more(predicate: P) -> RepeatToolMin<Self, TrueParser>
pub const fn new_one_or_more(predicate: P) -> RepeatToolMin<Self, TrueParser>
Creates a tool that matches one or more occurrences of characters that satisfy the specified predicate.