Some usefult parsing atoms;
Structs
- AnyChar
- Matches any single character.
- Check
InvTool - Matches only if the provided atom doesn’t match.
- Check
Tool - Only checks the provided atom, without progressing.
- EOFChar
- Parses only the end of the input
- NonEmpty
- Discards empty strings from a match.
- Predicate
Atom - Tool that matches characters which satisfies the provided predicate.
- Predicate
RefAtom - Tool that matches characters which satisfies the provided ref predicate.
- True
Atom - Matches the empty string, therefore it always matches.
Functions
- repeat_
any_ bounds - Repeat atom with the specified limits without a separator
- repeat_
any_ unbounded - Repeat atom with the specified limits without a separator
- repeat_
bounds - Repeat atom with the specified limits without a separator
- repeat_
unbounded - Repeat atom with the specified limits without a separator