Parsing atoms
This module provides the Atom trait and some parsing atoms which incapsulates some
basic algorithms which you can use to define more sofisticated ones.
Structs
- Match
- Data obtained from a successful match.
- Match
Helper - String view with accessory matching methods.
Traits
- Always
Atom - A atom that always matches.
- Atom
- The main parsing trait