pub struct TupData<D, M> { /* private fields */ }Available on crate features
unstable-features only.Expand description
Utility for saving intermediate values.
Complex parsing tools usually use several other tools to perform to perform simple
subtasks. However, dealing with many of these tools makes harder to keep consistent both
returned data and the total length of the match, which we remember should be consistent
with the number of bytes skipped by the View object.
This object keeps an instance of intermediate returned data, actual number of bytes skipped
and the last instance of View, keeping them consistent.
Implementations
Sourceimpl<D, M> TupData<D, M>
impl<D, M> TupData<D, M>
Sourceimpl<'a, D> TupData<D, View<'a>>
impl<'a, D> TupData<D, View<'a>>
Sourcepub fn chain_replace<T>(
self,
t: &T,
) -> Result<TupData<T::Data, View<'a>>, T::Error>where
T: Tool<'a>,
pub fn chain_replace<T>(
self,
t: &T,
) -> Result<TupData<T::Data, View<'a>>, T::Error>where
T: Tool<'a>,
Match a Tool and replace stored data with returned data.
Sourcepub fn chain_nodata<T>(self, t: &T) -> Result<Self, T::Error>where
T: Tool<'a>,
pub fn chain_nodata<T>(self, t: &T) -> Result<Self, T::Error>where
T: Tool<'a>,
Match a Tool but discards returned data.
Sourcepub fn chain_save<T>(
self,
t: &T,
) -> Result<TupData<(D, T::Data), View<'a>>, T::Error>where
T: Tool<'a>,
pub fn chain_save<T>(
self,
t: &T,
) -> Result<TupData<(D, T::Data), View<'a>>, T::Error>where
T: Tool<'a>,
Match a Tool and keeps both saved and returned data.