Parsing tools
This module provides the ParseTool trait and some parsing tools which incapsulates some
basic algorithms which you can use to define more sofisticated ones.
Structs
- EOFTool
- Parses only the end of the input
- Named
- A named parsing tool.
- Named
Error - Error type for
Named. - OrTool
- Tool that matches at least one of two subtools
- OrTool
Err - Error type for
OrTool - Predicate
Tool - Tool that matches characters which satisfies the provided predicate.
- Repeat
Tool - Tool that matches repetitions with separator
- True
Parser - Matches the empty string, therefore it always matches.
Enums
- OrTool
Data - Result type for
OrTool - Repeat
Tool Err - Error type for
RepeatTool
Traits
- Parse
Tool - The main parsing trait