Position

Struct Position 

pub struct Position<FILE = NoFile> { /* private fields */ }
A position.

Characters in a text file can be organizes in a virtual grid in order to easily find characters or parsing errors inside the file. Each file can be divided in multiple lines separated by line feed (U+000A) or carriage return + line feed (U+000D + U+000A).

To find a character then you need just the index of the line containing it (the first line has index 0) and the character index inside thai line (also called the column).

Type F is any type that can be used to identify a text file, for example a String, a Path or a custom type that implements at least Clone in order to provide maximum compatibility with other objects in this crate, even it is not strictly required.

If you work on a single file and/or you don’t want to take in account the used file just put NoFile as F.

Implementations

Source

impl<F> Position<F>

pub const fn new_file(file: F, line: u32, column: u32) -> Self

Create a new Position at specified file, line and column indices

pub const fn new_file_zero(file: F) -> Self

Create a new Position with line=0 and column=0

pub const fn file(&self) -> &F

Get the file identifier

pub const fn line(&self) -> u32

Get the line number

pub const fn column(&self) -> u32

Get the column number

pub const fn make_ref(&self) -> Position<&F>

Converts it to a reference

pub fn unpack(self) -> (u32, u32, F)

Unpacks the position.

The first integer is the line number, the second one the column number

Source

impl<F> Position<F>
where F: Default,

pub fn new(line: u32, column: u32) -> Self

Like Position::new_file but with file argument set to F::default()

pub fn new_zero() -> Self

Like Position::new_file_zero but with file argument set to F::default()