Characters in a text file can be organizes in a virtual grid in order to easily find characters
or parsing errors inside the file. Each file can be divided in multiple lines separated by
line feed (U+000A) or carriage return + line feed (U+000D + U+000A).
To find a character then you need just the index of the line containing it (the first line has index 0)
and the character index inside thai line (also called the column).
Type F is any type that can be used to identify a text file, for example a
String, a Path or a custom type that implements
at least Clone in order to provide maximum compatibility with other objects in this crate,
even it is not strictly required.
If you work on a single file and/or you don’t want to take
in account the used file just put NoFile as F.