Simple predicates for characters.
This module contains some useful functions in order to analize ASCII and Unicode characters.
A lot of predicates already available for char type are not included here, even if they are
quite useful.
Structs
- Alphabetic
Tool - Tests if
is_alphabeticis true. - Alphanumeric
Tool - Tests if
is_alphanumericis true. - Ascii
Alphabetic Tool - Tests if
is_ascii_alphabeticis true. - Ascii
Alphanumeric Tool - Tests if
is_ascii_alphanumericis true. - Ascii
Digit Tool - Tests if
is_ascii_digitis true. - Ascii
Tool - Tests if
is_asciiis true. - Numeric
Tool - Tests if
is_numericis true. - Whitespace
Tool - Tests if
is_whitespaceis true.
Functions
- is_
lu_ letter - Unicode lowercase/uppercase letter
- is_
newline - Tests if a character is a newline character (U+000A,
\n). Carriage return (U+000D,\r) is not detected by this function because it is usually followed by the newline character.