Module predicates

Simple predicates for characters.

This module contains some useful functions in order to analize ASCII and Unicode characters.

A lot of predicates already available for char type are not included here, even if they are quite useful.

Here an incomplete list of other predicates defined as char associate functions:

Functions

is_lu_letter
Unicode lowercase/uppercase letter
is_newline
Tests if a character is a newline character (U+000A, \n). Carriage return (U+000D, \r) is not detected by this function because it is usually followed by the newline character.