Struct minparser::Pos

source ·
pub struct Pos<T, FILE = ()> { /* private fields */ }
A positioned object, functionally equivalent to a struct containing an object of type T (the wrapped object) and its position as a Position<FILE> object.

A parser uses characters inside a text file to create more complex objects. When the parsing fails due to a syntax error you must inform the user about it, in particular you need to tell the user where is the error.

This type associates to a type T (usually a token) a Position that allows the user to locate it inside the file

Implementations

source

impl<T, F> Pos<T, F>

source

pub fn new(el: T, pos: Position<F>) -> Self

Creates a new positioned object. See also Posable::at

source

pub fn new_pos(el: T, file: F, line: u32, column: u32) -> Self

Creates a new positioned object. See also Posable::at_pos

source

pub fn file(&self) -> &F

Get the file identifier

source

pub fn line(&self) -> u32

Get the line number

source

pub fn column(&self) -> u32

Get the column number

source

pub fn mov<G>(self, pos: Position<G>) -> Pos<T, G>

Moves the content to a different position

source

pub fn mov_to<U, G>(self, ot: Pos<U, G>) -> Pos<T, G>

Moves the content to a different position

source

pub fn pos(&self) -> &Position<F>

Gets the position

source

pub fn take(self) -> T

Consumes the objects and returns the wrapped element

source

pub fn take_pos(self) -> Position<F>

Consumes the objects and returns the position

source

pub fn take_all(self) -> (T, Position<F>)

Consumes the objects and returns both the wrapped element and the position

source

pub fn test<TF: FnOnce(&T) -> bool>(&self, f: TF) -> bool

Tests the wrapped object

source

pub fn test_pos<TF: FnOnce(&T, &Position<F>) -> bool>(&self, f: TF) -> bool

Tests both the wrapped object and its position

source

pub fn map<U, MF: FnOnce(T) -> U>(self, f: MF) -> Pos<U, F>

Apply f at the wrapped object

source

pub fn map_pos<U, G, MF: FnOnce(T, Position<F>) -> (U, Position<G>)>( self, f: MF, ) -> Pos<U, G>

Apply f at the wrapped object and its position

source

pub fn make_ref<'a>(&'a self) -> Pos<&'a T, F>
where F: Clone,

Converts it to a reference

source

pub fn make_mut<'a>(&'a mut self) -> Pos<&'a mut T, F>
where F: Clone,

Converts it to a mutable reference

source

impl<T, E, F> Pos<Result<T, E>, F>

source

pub fn throw(self) -> Result<Pos<T, F>, Pos<E, F>>

Converts a Pos<Result<T, E>, F> into Result<Pos<T, F>, Pos<E, F>> that can be used with the ? operator

source

pub fn throw_el(self) -> Result<Pos<T, F>, E>

Converts a Pos<Result<T, E>, F> into Result<Pos<T, F>, E> that can be used with the ? operator

source

pub fn throw_err(self) -> Result<T, Pos<E, F>>

Converts a Pos<Result<T, E>, F> into Result<T, Pos<E, F>> that can be used with the ? operator

source

impl<T, F> Pos<Option<T>, F>

source

pub fn ok_or<E>(self, err: E) -> Result<Pos<T, F>, Pos<E, F>>

Applies Option::ok_or to the wrapped object and then Pos::throw the resulting object

source

pub fn ok_or_err<E>(self, err: E) -> Result<T, Pos<E, F>>

Applies Option::ok_or to the wrapped object and then Pos::throw_err the resulting object

source

impl<B, C, F> Pos<ControlFlow<B, C>, F>

source

pub fn try_break(self) -> ControlFlow<Pos<B, F>, C>

Converts a Pos<ControlFlow<B, C>, F> into a ControlFlow<Pos<B, F>, C> by moving the resulting Position to the break case