Parsing tools
This module provides the ParseTool trait and some parsing tools which incapsulates some
basic algorithms which you can use to define more sofisticated ones.
Structs
- AnyTool
- Matches any character.
- Check
InvTool - Matches only if the provided tool doesn’t match.
- Check
Tool - Only checks the provided tool, without progressing.
- EOFTool
- Parses only the end of the input
- GetChar
- Get matched character in
PredicateToolandPredicateRefTool. - Lazy
NoTerm - Unit struct for
LazyRepeatToolin order to return a matching string withoutTERM. - Lazy
Repeat Tool - Tool that matches repetitions lazily.
- Or
- Tool that matches at least one of many subtools.
- Predicate
RefTool - Tool that matches characters which satisfies the provided ref predicate.
- Predicate
Tool - Tool that matches characters which satisfies the provided predicate.
- Repeat
Tool - Tool that matches repetitions with separator requiring a minimum number of repetitions.
- SeqTool
- Tool that matches a sequence of subtools.
- Tool
Result Err - Error tyoe for
ToolResult. - Transform
- Transform the matched character in
PredicateToolandPredicateRefTool. - True
Parser - Matches the empty string, therefore it always matches.
Enums
- Tool
Result - Return type of a
ParseTool. - Tool
Result Data - Return type of a
ParseToolData.
Traits
- Parse
Tool - The main parsing trait
- Parse
Tool Data - A tool that can generate additional
Dataafter a successful match.