Module tools

Parsing tools

This module provides the ParseTool trait and some parsing tools which incapsulates some basic algorithms which you can use to define more sofisticated ones.

Structs

AnyTool
Matches any character.
EOFTool
Parses only the end of the input
JoinTool
Tool that wraps a function that accepts a View object.
LazyRepeatTool
Tool that matches repetitions lazily.
Or
Tool that matches at least one of many subtools.
OrTool
Tool that matches at least one of two subtools
PredicateRefTool
Tool that matches characters which satisfies the provided ref predicate.
PredicateTool
Tool that matches characters which satisfies the provided predicate.
RepeatTool
Tool that matches repetitions with separator
RepeatToolMin
Tool that matches repetitions with separator requiring a minimum number of repetitions.
SeqTool
Tool that matches a sequence of subtools.
TrueParser
Matches the empty string, therefore it always matches.

Traits

ParseTool
The main parsing trait