Parsing tools
This module provides the ParseTool trait and some parsing tools which incapsulates some
basic algorithms which you can use to define more sofisticated ones.
Structs
- AnyTool
- Matches any character.
- EOFTool
- Parses only the end of the input
- Join
Tool - Tool that wraps a function that accepts a
Viewobject. - Lazy
Repeat Tool - Tool that matches repetitions lazily.
- Or
- Tool that matches at least one of many subtools.
- OrTool
- Tool that matches at least one of two subtools
- Predicate
RefTool - Tool that matches characters which satisfies the provided ref predicate.
- Predicate
Tool - Tool that matches characters which satisfies the provided predicate.
- Repeat
Tool - Tool that matches repetitions with separator
- Repeat
Tool Min - Tool that matches repetitions with separator requiring a minimum number of repetitions.
- SeqTool
- Tool that matches a sequence of subtools.
- True
Parser - Matches the empty string, therefore it always matches.
Traits
- Parse
Tool - The main parsing trait