pub struct NonEmpty<P>(pub P);Expand description
Discards empty strings from a match.
Some atoms that needs to match an undefined number of other atoms (like
Repeat or LazyRepeat)
may enter in an infinite loop if the inner atom matches an empty string "".
In that case there is always a match but the atom does not progress, resulting so in an
endless cycle.
This tool takes another tool and converts any match with an empty string with a missing match, avoiding this issue.
Tuple Fields
0: PTrait Implementations
impl<P: Copy> Copy for NonEmpty<P>